summaryrefslogtreecommitdiff
path: root/libgo/go/net/dial_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'libgo/go/net/dial_test.go')
-rw-r--r--libgo/go/net/dial_test.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/libgo/go/net/dial_test.go b/libgo/go/net/dial_test.go
index 3a2c59a2d1d..1bf96fd3ce3 100644
--- a/libgo/go/net/dial_test.go
+++ b/libgo/go/net/dial_test.go
@@ -463,7 +463,7 @@ func TestDialParallelSpuriousConnection(t *testing.T) {
origTestHookDialTCP := testHookDialTCP
defer func() { testHookDialTCP = origTestHookDialTCP }()
testHookDialTCP = func(ctx context.Context, net string, laddr, raddr *TCPAddr) (*TCPConn, error) {
- // Sleep long enough for Happy Eyeballs to kick in, and inhibit cancelation.
+ // Sleep long enough for Happy Eyeballs to kick in, and inhibit cancellation.
// This forces dialParallel to juggle two successful connections.
time.Sleep(fallbackDelay * 2)
@@ -865,7 +865,7 @@ func TestCancelAfterDial(t *testing.T) {
d := &Dialer{Cancel: cancel}
c, err := d.Dial("tcp", ln.Addr().String())
- // Immediately after dialing, request cancelation and sleep.
+ // Immediately after dialing, request cancellation and sleep.
// Before Issue 15078 was fixed, this would cause subsequent operations
// to fail with an i/o timeout roughly 50% of the time.
close(cancel)
@@ -973,11 +973,11 @@ func TestDialerControl(t *testing.T) {
}
// mustHaveExternalNetwork is like testenv.MustHaveExternalNetwork
// except that it won't skip testing on non-iOS builders.
func mustHaveExternalNetwork(t *testing.T) {
t.Helper()
- ios := runtime.GOOS == "darwin" && (runtime.GOARCH == "arm" || runtime.GOARCH == "arm64")
- if testenv.Builder() == "" || ios {
+ mobile := runtime.GOOS == "android" || runtime.GOOS == "darwin" && (runtime.GOARCH == "arm" || runtime.GOARCH == "arm64")
+ if testenv.Builder() == "" || mobile {
testenv.MustHaveExternalNetwork(t)
}
}
@@ -973,11 +973,11 @@ func TestDialerControl(t *testing.T) {
}
// mustHaveExternalNetwork is like testenv.MustHaveExternalNetwork
-// except that it won't skip testing on non-iOS builders.
+// except that it won't skip testing on non-mobile builders.
func mustHaveExternalNetwork(t *testing.T) {
t.Helper()